@@ -2,7 +2,7 @@
  *
  * Variable length lists of atoms (or other integers).
  *
- * $Id: list.h,v 1.7 2000/02/02 22:42:49 nisse Exp $ */
+ * $Id: list.h,v 1.8 2000/07/27 22:30:28 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -61,7 +61,11 @@
 */
 
 #define LIST(x) ((x)->elements)
+#define LIST_LENGTH(x) ((x)->super.length)
+
+#if 0
 #define LIST_LENGTH(x) (((struct list_header *) (x))->length)
+#endif
 
 struct list_header *lsh_list_alloc(struct lsh_class *class,
 				   unsigned length, size_t element_size);
